Package: fit.models
Version: 0.64
Date: 2020-08-02
Title: Compare Fitted Models
Description: The fit.models function and its associated methods (coefficients, print,
  summary, plot, etc.) were originally provided in the robust package to compare robustly
  and classically fitted model objects. See chapters 2, 3, and 5 in Insightful (2002)
  'Robust Library User's Guide' <http://robust.r-forge.r-project.org/Robust.pdf>). The aim
  of the fit.models package is to separate this fitted model object comparison functionality
  from the robust package and to extend it to support fitting methods (e.g., classical,
  robust, Bayesian, regularized, etc.) more generally.
Authors@R: person("Kjell", "Konis", role = c("aut", "cre"), email = "kjellk@gmail.com")
Author: Kjell Konis [aut, cre]
Maintainer: Kjell Konis <kjellk@gmail.com>
Imports: lattice, stats
Suggests: MASS
License: GPL
RoxygenNote: 7.1.0
NeedsCompilation: no
Packaged: 2020-08-02 13:59:06 UTC; kjellk
Repository: CRAN
Date/Publication: 2020-08-02 14:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 16:07:51 UTC; unix
