# Generated by roxygen2: do not edit by hand

S3method(center,default)
S3method(coef,glmfm)
S3method(coef,lmfm)
S3method(designMD,default)
S3method(plot,covfm)
S3method(plot,glmfm)
S3method(plot,lmfm)
S3method(print,covfm)
S3method(print,glmfm)
S3method(print,lmfm)
S3method(print,summary.covfm)
S3method(print,summary.glmfm)
S3method(print,summary.lmfm)
S3method(summary,covfm)
S3method(summary,glmfm)
S3method(summary,lmfm)
S3method(vcor,default)
S3method(vcov,default)
export(center)
export(ddPlot.covfm)
export(designMD)
export(distancePlot.covfm)
export(ellipsesPlot.covfm)
export(fit.models)
export(fmclass.add.class)
export(fmclass.register)
export(overlaidKernelDensityPlot)
export(overlaidQQPlot)
export(overlaidSimpleRegressionPlot)
export(screePlot.covfm)
export(sideBySideIndexPlot)
export(sideBySideKernelDensityPlot)
export(sideBySideQQPlot)
export(sideBySideScatterPlot)
export(vcor)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,polygon)
importFrom(graphics,strheight)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(lattice,densityplot)
importFrom(lattice,llines)
importFrom(lattice,panel.abline)
importFrom(lattice,panel.densityplot)
importFrom(lattice,panel.loess)
importFrom(lattice,panel.rug)
importFrom(lattice,panel.text)
importFrom(lattice,panel.xyplot)
importFrom(lattice,qqmath)
importFrom(lattice,simpleKey)
importFrom(lattice,strip.default)
importFrom(lattice,xyplot)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,cov2cor)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,mahalanobis)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,qqnorm)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(utils,menu)

export(plot.glmfm)
